<?php
$TRANSLATIONS = array(
"Please provide a valid Dropbox app key and secret." => "Por favor, proporcioná un secreto y una contraseña válida para la aplicación Dropbox.",
"External storage" => "Almacenamiento externo",
"Location" => "Ubicación",
"Host" => "Servidor",
"Username" => "Nombre de usuario",
"Password" => "Contraseña",
"Share" => "Compartir",
"URL" => "URL",
"Access granted" => "Acceso permitido",
"Error configuring Dropbox storage" => "Error al configurar el almacenamiento de Dropbox",
"Grant access" => "Permitir acceso",
"Error configuring Google Drive storage" => "Error al configurar el almacenamiento de Google Drive",
"Personal" => "Personal",
"Saved" => "Guardado",
"Name" => "Nombre",
"External Storage" => "Almacenamiento externo",
"Folder name" => "Nombre de la carpeta",
"Configuration" => "Configuración",
"Options" => "Opciones",
"Add storage" => "Añadir almacenamiento",
"All Users" => "Todos los usuarios",
"Groups" => "Grupos",
"Users" => "Usuarios",
"Delete" => "Borrar",
"Enable User External Storage" => "Habilitar almacenamiento de usuario externo",
"SSL root certificates" => "certificados SSL raíz",
"Import Root Certificate" => "Importar certificado raíz"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
